@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample-extension.c,v 1.4 2004/12/30 22:42:23 chpe Exp $
+ *  $Id: ephy-sample-extension.c,v 1.7 2006/09/13 19:01:28 chpe Exp $
  */
 
 #include "config.h"
@@ -49,7 +49,7 @@ ephy_sample_extension_init (EphySampleExtension *extension)
 {
 	extension->priv = EPHY_SAMPLE_EXTENSION_GET_PRIVATE (extension);
 
-	LOG ("EphySampleExtension initialising")
+	LOG ("EphySampleExtension initialising");
 }
 
 static void
@@ -58,7 +58,7 @@ ephy_sample_extension_finalize (GObject *object)
 /*
 	EphySampleExtension *extension = EPHY_SAMPLE_EXTENSION (object);
 */
-	LOG ("EphySampleExtension finalising")
+	LOG ("EphySampleExtension finalising");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -68,7 +68,7 @@ impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 //	EphySampleExtension *extension = EPHY_SAMPLE_EXTENSION (ext);
-	LOG ("EphySampleExtension attach_window")
+	LOG ("EphySampleExtension attach_window");
 }
 
 static void
@@ -76,7 +76,7 @@ impl_detach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 //	EphySampleExtension *extension = EPHY_SAMPLE_EXTENSION (ext);
-	LOG ("EphySampleExtension detach_window")
+	LOG ("EphySampleExtension detach_window");
 }
 
 static void
@@ -84,7 +84,7 @@ impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
 		 EphyTab *tab)
 {
-	LOG ("attach_tab")
+	LOG ("attach_tab");
 }
 
 static void
@@ -92,7 +92,7 @@ impl_detach_tab (EphyExtension *ext,
 		 EphyWindow *window,
 		 EphyTab *tab)
 {
-	LOG ("detach_tab")
+	LOG ("detach_tab");
 }
 
 static void
@@ -157,7 +157,7 @@ ephy_sample_extension_get_type (void)
 GType
 ephy_sample_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySampleExtensionClass),
 		NULL, /* base_init */
@@ -170,7 +170,7 @@ ephy_sample_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_sample_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_sample_extension_iface_init,
 		NULL,
